<?php namespace Config;

// Create a new instance of our RouteCollection class.
$routes = Services::routes(true);

// Load the system's routing file first, so that the app and ENVIRONMENT
// can override as needed.
if (file_exists(SYSTEMPATH . 'Config/Routes.php'))
{
	require SYSTEMPATH . 'Config/Routes.php';
}

/**
 * --------------------------------------------------------------------
 * Router Setup
 * --------------------------------------------------------------------
 */
$routes->setDefaultNamespace('App\Controllers');
$routes->setDefaultController('Home');
$routes->setDefaultMethod('index');
$routes->setTranslateURIDashes(false);
$routes->set404Override();
$routes->setAutoRoute(true);

/**
 * --------------------------------------------------------------------
 * Route Definitions
 * --------------------------------------------------------------------
 */

// We get a performance increase by specifying the default
// route since we don't have to scan directories.
$routes->get('/', 'Panel::index');
$routes->get('/domains', 'Panel::domains');
$routes->get('/domains/add', 'Panel::add_domain');
$routes->get('/domains/(:num)', 'Panel::edit_domain/$1');
$routes->get('/domains/download', 'PanelAjax::download_file');
$routes->get('/offers', 'Panel::offers');
$routes->get('/menu', 'Panel::menu');
$routes->get('/telegram', 'Panel::telegram_settings');
$routes->get('/email', 'Panel::email_settings');
$routes->get('/recaptcha', 'Panel::recaptcha_settings');
$routes->get('/settings', 'Panel::general_settings');
$routes->get('/profile', 'Panel::profile_settings');
$routes->get('/front', 'Front::index');
$routes->post('/front/offer', 'Front::offer');;
$routes->get('/login', 'PanelLogin::index');
$routes->get('/logout', 'Panel::logout');
$routes->post('/login', 'PanelLogin::post');
$routes->post('/menu', 'PanelAjax::settings_save/menu');
$routes->post('/telegram', 'PanelAjax::settings_save/telegram');
$routes->post('/email', 'PanelAjax::settings_save/email');
$routes->post('/settings', 'PanelAjax::settings_save/settings');
$routes->post('/recaptcha', 'PanelAjax::settings_save/recaptcha');
$routes->post('/profile', 'PanelAjax::settings_save/profile');
$routes->post('/domains/add', 'PanelAjax::add_domain');
$routes->post('/domains/(:num)', 'PanelAjax::edit_domain/$1');
$routes->post('/domains/delete/(:num)', 'PanelAjax::delete_domain/$1');
$routes->post('/offers/delete/(:num)', 'PanelAjax::delete_offer/$1');
$routes->post('/offers/(:num)', 'PanelAjax::seen_offer/$1');

/**
 * --------------------------------------------------------------------
 * Additional Routing
 * --------------------------------------------------------------------
 *
 * There will often be times that you need additional routing and you
 * need to it be able to override any defaults in this file. Environment
 * based routes is one such time. require() additional route files here
 * to make that happen.
 *
 * You will have access to the $routes object within that file without
 * needing to reload it.
 */
if (file_exists(APPPATH . 'Config/' . ENVIRONMENT . '/Routes.php'))
{
	require APPPATH . 'Config/' . ENVIRONMENT . '/Routes.php';
}
